==> activity-center-api-0.16.59-20240325.020301-2-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/LayerSkinTagInfoDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

public class LayerSkinTagInfoDto extends BaseDto {

    /**
     * id
     */
    private Long id;

    /**
     * 模版ID
     */
    private Long industryTemplateId;

    /**
     * 主标题标签
     */
    private String mainTitleTag;

    /**
     * 副标题标签
     */
    private String subheadTag;

    /**
     * 利益点标签
     */
    private String benefitTag;

    /**
     * 商品图标签ID
     */
    private String tradeChartTag;


    public LayerSkinTagInfoDto() {

    }

    public LayerSkinTagInfoDto(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getMainTitleTag() {
        return mainTitleTag;
    }

    public void setMainTitleTag(String mainTitleTag) {
        this.mainTitleTag = mainTitleTag;
    }

    public String getSubheadTag() {
        return subheadTag;
    }

    public void setSubheadTag(String subheadTag) {
        this.subheadTag = subheadTag;
    }

    public String getBenefitTag() {
        return benefitTag;
    }

    public void setBenefitTag(String benefitTag) {
        this.benefitTag = benefitTag;
    }

    public String getTradeChartTag() {
        return tradeChartTag;
    }

    public void setTradeChartTag(String tradeChartTag) {
        this.tradeChartTag = tradeChartTag;
    }

    public Long getIndustryTemplateId() {
        return industryTemplateId;
    }

    public void setIndustryTemplateId(Long industryTemplateId) {
        this.industryTemplateId = industryTemplateId;
    }
}

==> activity-center-api-0.16.62-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/LayerSkinTagInfoDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

public class LayerSkinTagInfoDto extends BaseDto {

    /**
     * id
     */
    private Long id;

    /**
     * 模版ID
     */
    private Long industryTemplateId;

    /**
     * 主标题标签
     */
    private String mainTitleTag;

    /**
     * 副标题标签
     */
    private String subheadTag;

    /**
     * 利益点标签
     */
    private String benefitTag;

    /**
     * 商品图标签ID
     */
    private String tradeChartTag;

    /**
     * 行业
     */
    private String newTrade;

    /**
     * 玩法标签
     */
    private String playingTag;

    /**
     * 素材标签特征值1
     */
    private String materialCatg;

    /**
     * 素材标签特征值2
     */
    private String materialAllCatg;

    public LayerSkinTagInfoDto() {

    }

    public LayerSkinTagInfoDto(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getMainTitleTag() {
        return mainTitleTag;
    }

    public void setMainTitleTag(String mainTitleTag) {
        this.mainTitleTag = mainTitleTag;
    }

    public String getSubheadTag() {
        return subheadTag;
    }

    public void setSubheadTag(String subheadTag) {
        this.subheadTag = subheadTag;
    }

    public String getBenefitTag() {
        return benefitTag;
    }

    public void setBenefitTag(String benefitTag) {
        this.benefitTag = benefitTag;
    }

    public String getTradeChartTag() {
        return tradeChartTag;
    }

    public void setTradeChartTag(String tradeChartTag) {
        this.tradeChartTag = tradeChartTag;
    }

    public Long getIndustryTemplateId() {
        return industryTemplateId;
    }

    public void setIndustryTemplateId(Long industryTemplateId) {
        this.industryTemplateId = industryTemplateId;
    }

    public String getNewTrade() {
        return newTrade;
    }

    public void setNewTrade(String newTrade) {
        this.newTrade = newTrade;
    }

    public String getPlayingTag() {
        return playingTag;
    }

    public void setPlayingTag(String playingTag) {
        this.playingTag = playingTag;
    }

    public String getMaterialCatg() {
        return materialCatg;
    }

    public void setMaterialCatg(String materialCatg) {
        this.materialCatg = materialCatg;
    }

    public String getMaterialAllCatg() {
        return materialAllCatg;
    }

    public void setMaterialAllCatg(String materialAllCatg) {
        this.materialAllCatg = materialAllCatg;
    }
}
